@@ -1,6 +1,6 @@
 from .arithmetic import Add, Sub, Mul, Div, Pow, add, sub, mul, div, pow
 from .math import Log, Exp, Sin, Cos, Tan, Sqrt, Cbrt, Log10, Log2, Abs, Clip, log, exp, sin, cos, tan, sqrt, cbrt, log10, log2, abs, clip
-from .linalg import MatMul, TensorDot, Transpose, matmul, dot, tensordot, transpose
+from .linalg import MatMul, TensorDot, Transpose, EinSum, matmul, dot, tensordot, einsum, transpose
 from .tensor_ops import Reshape, Flatten, Squeeze, ExpandDims, Pad, SlidingWindowView, \
 reshape, flatten, squeeze, expand_dims, pad, sliding_window_view, newaxis
 from .activations import ReLU, LeakyReLU, ReLU6, Sigmoid, Softmax, Tanh, relu, leaky_relu, relu6, sigmoid, softmax, tanh
