@@ -6,6 +6,7 @@ from typing import TYPE_CHECKING, Union, Tuple, Sequence
 from numpy.typing import ArrayLike
 if TYPE_CHECKING:
     from neurograd.tensor import Tensor
+import gc
 
 
 
@@ -179,7 +180,7 @@ class Pad(Function, Module):
         if not hasattr(self, "pad_width"):
             raise RuntimeError("pad_width not set; call forward() first.")
         del parent_tensors[0].data  # free parent tensor data to save memory
-        ng.flush()
+        ng.flush(gc=False)
         slices = tuple(slice(l, None if u == 0 else -u) for (l, u) in self.pad_width)
         parent_tensors[0].data = output_tensor.data[slices]
 
